# runtime.platform

## Purpose
Domain runtime primitives for platform.

## Owns
- Modules under `vyro.runtime.platform`.

## Entry Points
- `vyro.runtime.platform`

## Not Here
- Public app composition (`vyro.app`).
